@@ -4,7 +4,7 @@ import shutil
 import tempfile
 from pathlib import Path
 
-from cached_path.common import get_cache_dir, set_cache_dir
+from .common import get_cache_dir, set_cache_dir
 
 
 class BaseTestClass:
